'use strict';

describe('ContactPageCtrl test', function() {
	var scope; //we'll use this scope in our tests

	//mock Application to allow us to inject our own dependencies
	beforeEach(function() {
		module('SCHEMAcat');
	});
	describe('load ContactPageCtrl default (animated)', function() {
		//mock the controller for the same reason and include $rootScope and $controller
		beforeEach(inject(function($controller, $rootScope, $route, Settings) {
			this.scope = $rootScope.$new();
			this.Settings = Settings;
			spyOn(this.scope, '$broadcast').andCallThrough();
			//declare the controller and inject our empty scope
			$controller('ContactPageCtrl', {
				$scope: this.scope,
				Settings: this.Settings
			});
		}));
		it('toNextPage should be false', function() {
			expect(this.scope.toNextPage).toBe(false);
		});
		it('assign animated CSS class', function() {
			expect(this.scope.animateInOut).toBe('animated slideInRight');
		});

		//Exit animation tests
		it('moving to "about" page. Should slide out to the right', function() {
			this.scope.$broadcast('$routeChangeStart', {
				templateUrl: 'partials/about.html'
			});
			expect(this.scope.$broadcast).toHaveBeenCalledWith('$routeChangeStart', {
				templateUrl: 'partials/about.html'
			});
			expect(this.scope.animateInOut).toBe('animated slideOutRight');
		});
		it('moving to "workspace" page. Should slide out to the right', function() {
			this.scope.$broadcast('$routeChangeStart', {
				templateUrl: 'partials/workspace.html'
			});
			expect(this.scope.$broadcast).toHaveBeenCalledWith('$routeChangeStart', {
				templateUrl: 'partials/workspace.html'
			});
			expect(this.scope.animateInOut).toBe('animated slideOutRight');
		});
		it('moving to any other page. Should fade out down', function() {
			this.scope.$broadcast('$routeChangeStart', {
				templateUrl: null
			});
			expect(this.scope.$broadcast).toHaveBeenCalledWith('$routeChangeStart', {
				templateUrl: null
			});
			expect(this.scope.animateInOut).toBe('animated fadeOutDown');
		});

		//enter animation tests
		it('moving from "about" page. Should slide in from the right', function() {
			this.scope.$broadcast('$routeChangeSuccess', null, {
				templateUrl: 'partials/about.html'
			});
			expect(this.scope.animateInOut).toBe('animated slideInRight');
		});
		it('moving from "workspace" page. Should slide in from the right', function() {
			this.scope.$broadcast('$routeChangeSuccess', null, {
				templateUrl: 'partials/workspace.html'
			});
			expect(this.scope.animateInOut).toBe('animated slideInRight');
		});
		it('moving from any other page. Should fade in down', function() {
			this.scope.$broadcast('$routeChangeSuccess', null, {
				templateUrl: null
			});
			expect(this.scope.animateInOut).toBe('animated fadeInDown');
		});


		describe('load ContactPageCtrl non-animated', function() {

			beforeEach(inject(function($controller, $rootScope, $route, Settings) {
				this.scope = $rootScope.$new();
				this.Settings = Settings;
				this.Settings.setAnimationStatus(false);
				//declare the controller and inject our empty scope
				$controller('ContactPageCtrl', {
					$scope: this.scope,
					Settings: this.Settings
				});
			}));

			it('animate.css classes are not assigned', function() {
				expect(this.scope.animateInOut).toBe(undefined);
			})
		});
	});
});